<?php
if ( ! class_exists( 'DH_Woocommerce' ) && defined('WOOCOMMERCE_VERSION') ) :
	class DH_Woocommerce {
	
		protected static $_instance = null;
	
		public function __construct() {
			add_action( 'init', array( &$this, 'init' ) );
			add_shortcode('product_categories_grid', array(&$this,'product_categories_grid_shortcode'));
			if(!is_admin())
				add_action( 'template_redirect', array( &$this, 'add_navbar_minicart' ) );
			global $pagenow;
			if ( is_admin() && isset( $_GET['activated'] ) && $pagenow === 'themes.php' ) {
				add_action( 'init', array( &$this, 'update_product_image_size' ), 1 );
			}
			if(is_admin()){
				add_action( 'created_term', array(&$this,'product_cat_heading_save'), 10,3 );
				add_action( 'edit_term',array(&$this, 'product_cat_heading_save'), 10,3 );
			
				//cat heading
				add_action('product_cat_add_form_fields',array(&$this,'product_tax_add_heading_fields'),20,3);
				add_action('product_cat_edit_form_fields',array(&$this,'product_tax_edit_heading_fields'),20,3);
			
				//tag heading
				add_action('product_tag_add_form_fields',array(&$this,'product_tax_add_heading_fields'),20,3);
				add_action('product_tag_edit_form_fields',array(&$this,'product_tax_edit_heading_fields'),20,3);
			
			
				//brand heading
				add_action('product_brand_add_form_fields',array(&$this,'product_tax_add_heading_fields'),20,3);
				add_action('product_brand_edit_form_fields',array(&$this,'product_tax_edit_heading_fields'),20,3);
			}
			add_action( 'wp_ajax_dh_json_search_products', array( &$this, 'json_search_products' ) );
		}

		public static function instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}
		
		public function init() {
			if ( ! defined( 'WOOCOMMERCE_VERSION' ) ) {
				return;
			}
			
			//add_action( 'wp_enqueue_scripts', array( &$this, 'removeprettyPhoto' ), 199 );
			remove_shortcode('woocommerce_cart');
			add_shortcode('woocommerce_cart',array(__CLASS__,'woocommerce_cart'));
			
			if ( version_compare( WOOCOMMERCE_VERSION, "2.1" ) >= 0 ) {
				// WooCommerce 2.1 or above is active
				add_filter( 'woocommerce_enqueue_styles', '__return_false' );
			} else {
				// WooCommerce is less than 2.1
				define( 'WOOCOMMERCE_USE_CSS', false );
			}
			
			//WooCommerce 2.6 hooks
			remove_filter( 'post_class', 'wc_product_post_class', 20, 3 );
			
			//WooCommerce 2.5 action
			remove_action( 'woocommerce_before_subcategory', 'woocommerce_template_loop_category_link_open', 10 );
			remove_action( 'woocommerce_after_subcategory', 'woocommerce_template_loop_category_link_close', 10 );
			remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
			remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );
			
			add_filter('dh_use_feature_product_image_in_single', '__return_true');
			
			// remove wrapper
			remove_action( 'woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10 );
			remove_action( 'woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10 );
			
			//remove result count
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
			
			// remove page title
			add_filter( 'woocommerce_show_page_title', '__return_false' );
			
			// remove default loop price
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
			
			// Loop shop per page
			add_filter( 'loop_shop_per_page', array( &$this, 'loop_shop_per_page' ) );
			// Loop thumbnail
			remove_action( 'woocommerce_before_shop_loop_item_title', 'woocommerce_template_loop_product_thumbnail', 10 );
			add_action( 'woocommerce_before_shop_loop_item_title', array( &$this, 'template_loop_product_thumbnail' ), 10 );
			
			if(apply_filters('dh_use_template_loop_product_frist_thumbnail', true)){
				add_action( 'woocommerce_before_shop_loop_item_title', array( &$this, 'template_loop_product_frist_thumbnail' ), 11 );
			}
			// Loop actions
			//add_action( 'woocommerce_after_shop_loop_item', array( &$this, 'template_loop_quickview' ), 11 );
			
			//wishlist
			add_action( 'woocommerce_before_shop_loop_item_title', array( &$this, 'template_loop_wishlist' ), 12 );
			
			// Quick view
			add_action( 'wp_ajax_wc_loop_product_quickview', array( &$this, 'quickview' ) );
			add_action( 'wp_ajax_nopriv_wc_loop_product_quickview', array( &$this, 'quickview' ) );
			
			// Remove minicart
			add_action( 'wp_ajax_wc_minicart_remove_item', array( &$this, 'minicart_remove_item' ) );
			add_action( 'wp_ajax_nopriv_wc_minicart_remove_item', array( &$this, 'minicart_remove_item' ) );
			// add_to_cart_fragments
			add_filter( 'add_to_cart_fragments', array( &$this, 'add_to_cart_fragments' ) );
			
			// Upsell products
			remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
			add_action( 'woocommerce_after_single_product_summary', array( &$this, 'upsell_display' ), 15 );
			
			// Related products
			add_filter( 'woocommerce_output_related_products_args', array( &$this, 'related_products_args' ) );
			
			// Cross sell products
			remove_action( 'woocommerce_cart_collaterals', 'woocommerce_cross_sell_display' );
			//add_action( 'woocommerce_cart_collaterals', array( &$this, 'cross_sell_display' ), 15 );
			
			//form field
			
			//remove_action('woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs',10);
			
			add_action('template_redirect', array(&$this,'single_fullwidth_layout'),99);
		}
		
		public static function woocommerce_cart(){
			return is_null( WC()->cart ) ? '' : WC_Shortcodes::shortcode_wrapper( array( 'WC_Shortcode_Cart', 'output' ),array(),array(
				'class'  => 'woocommerce-cart-wrap',
				'before' => null,
				'after'  => null
			) );
		}
		
		
		public function add_navbar_minicart(){
			$header_style = dh_get_theme_option('header-style','classic');
			// add minicart in nav
			// if($header_style =='classic')
			// 	add_filter( 'wp_nav_menu_items', array( &$this, 'navbar_minicart' ), 12, 2 );
		}

		public function single_fullwidth_layout(){
			if(is_product() ){
				$attachment_ids = wc_get_product(get_the_ID())->get_gallery_image_ids();
				if(empty($attachment_ids)){
					add_filter( 'dh_use_feature_product_image_in_single', '__return_true' );
				}
				add_action( 'woocommerce_single_product_summary', array( &$this, 'single_sharing' ), 50 );
			}
		}
		

		public static function content(){
			global $wp_query;
			?>
			<?php
			if ( is_singular( 'product' ) ) {
	
				while ( have_posts() ) : the_post();
	
					wc_get_template_part( 'content', 'single-product' );
	
				endwhile;
	
			} else { ?>
				<?php 
				/**
				 * script
				 * {{
				 */
				wp_enqueue_script('vendor-carouFredSel');
				?>
				<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>
	
					<h1 class="page-title"><?php woocommerce_page_title(); ?></h1>
	
				<?php endif; ?>
				
				<?php do_action( 'woocommerce_archive_description' ); ?>
				
				<?php if ( have_posts() ) : ?>
					<?php 
					$current_view_mode = dh_get_theme_option('dh_woocommerce_view_mode','grid');
					if(isset($_GET['mode']) && in_array($_GET['mode'], array('grid','list'))){
						$current_view_mode =  $_GET['mode'];
					}
					?>
					<?php if ( $wp_query->found_posts && woocommerce_products_will_display() ) {?>
					<div class="shop-toolbar">
						<?php woocommerce_result_count()?>
						<div class="view-mode">
							<a class="grid-mode<?php echo ($current_view_mode == 'grid' ? ' active' :'')?>" title="<?php esc_attr_e('Grid','sitesao')?>" href="#"><i class="fa fa-th-large"></i></a>
							<a class="list-mode<?php echo ($current_view_mode == 'list' ? ' active' :'')?>" title="<?php esc_attr_e('List','sitesao')?>" href="#"><i class="fa fa-bars"></i></a>
						</div>
						<?php woocommerce_catalog_ordering() ?>		
					</div>
					<?php }?>
					<div class="shop-loop <?php echo esc_attr($current_view_mode)?>">
					<?php if(is_search() && is_post_type_archive( 'product' )):?>
						<h3 class="woocommerce-search-text"><?php dh_page_title() ?></h3>
					<?php endif;?>
					<?php woocommerce_product_loop_start(); ?>
						<?php woocommerce_product_subcategories(); ?>
						<?php while ( have_posts() ) : the_post(); ?>
	
							<?php wc_get_template_part( 'content', 'product' ); ?>
	
						<?php endwhile; // end of the loop. ?>
					<?php woocommerce_product_loop_end(); ?>
					</div>
					<?php do_action('woocommerce_after_shop_loop'); ?>
	
				<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>
	
					<?php wc_get_template( 'loop/no-products-found.php' ); ?>
	
				<?php endif;
	
			}
		}
		
		public function cross_sell_display() {
			woocommerce_cross_sell_display( 3, 3 );
		}

		public function upsell_display() {
			if ( dh_get_theme_option( 'woo-product-layout', 'full-width' ) === 'full-width' ) {
				woocommerce_upsell_display( 4, 4 );
			} else {
				woocommerce_upsell_display( 3, 3 );
			}
		}

		public function related_products_args() {
			if ( dh_get_theme_option( 'woo-product-layout', 'full-width' ) === 'full-width' ) {
				$args = array( 'posts_per_page' => 12, 'columns' => 4 );
				return $args;
			}
			
			$args = array( 'posts_per_page' => 12, 'columns' => 3 );
			return $args;
		}
		
		// Number of products per page
		public function loop_shop_per_page() {
			$per_page = dh_get_theme_option( 'woo-per-page', 12 );
			if ( isset( $_GET['per_page'] ) )
				$per_page = absint( $_GET['per_page'] );
			return $per_page;
		}

		public function removeprettyPhoto() {
			wp_dequeue_style( 'woocommerce_prettyPhoto_css' );
			wp_dequeue_script( 'prettyPhoto-init' );
			wp_dequeue_script( 'prettyPhoto' );
		}

		public function update_product_image_size() {
			if ( ! defined( 'WOOCOMMERCE_VERSION' ) ) {
				return;
			}
			$catalog = array( 'width' => '400', 'height' => '500', 'crop' => 1 );
			$single = array( 'width' => '750', 'height' => '900', 'crop' => 1 );
			$thumbnail = array( 'width' => '100', 'height' => '120', 'crop' => 1 );
			
			update_option( 'shop_catalog_image_size', $catalog );
			update_option( 'shop_single_image_size', $single );
			update_option( 'shop_thumbnail_image_size', $thumbnail );
		}

		protected function _cart_items_text( $count ) {
			$product_item_text = "";
			
			if ( $count > 1 ) {
				$product_item_text = str_replace( '%', number_format_i18n( $count ), __( '% items', 'sitesao' ) );
			} elseif ( $count == 0 ) {
				$product_item_text = __( '0 items', 'sitesao' );
			} else {
				$product_item_text = __( '1 item', 'sitesao' );
			}
			
			return $product_item_text;
		}

		public function add_to_cart_fragments( $fragments ) {
			$fragments['div.minicart'] = $this->_get_minicart( true, true );
			$fragments['span.minicart-icon'] = $this->_get_minicart_icon();
			$fragments['a.cart-icon-mobile'] = $this->_get_minicart_mobile();
			$fragments['a.cart-icon-sidebar'] = $this->get_minicart_sidebar();
			return $fragments;
		}

		public function navbar_minicart( $items, $args ) {
			if ( $args->theme_location == 'primary' 
					&& defined( 'WOOCOMMERCE_VERSION' ) 
					&& dh_get_theme_option( 'woo-cart-nav', 1 )
				) {
				$items .= '<li class="navbar-minicart navbar-minicart-nav"></a>'.$this->_get_minicart(false,false,false).'</li>';
			}
			return $items;
		}

		public function minicart_remove_item() {
			global $woocommerce;
			$response = array();
			if ( ! isset( $_GET['item'] ) && ! isset( $_GET['_wpnonce'] ) ) {
				exit();
			}
			$woocommerce->cart->set_quantity( $_GET['item'], 0 );
			$cart_total = $woocommerce->cart->get_cart_total();
			$cart_count = absint($woocommerce->cart->cart_contents_count);
			$response['minicart_text'] = $cart_count;
			$response['minicart'] = $this->_get_minicart( true );
			// widget cart update
			ob_start();
			woocommerce_mini_cart();
			$mini_cart = ob_get_clean();
			$response['widget'] = '<div class="widget_shopping_cart_content">' . $mini_cart . '</div>';
			
			echo json_encode( $response );
			exit();
		}

		protected function _get_minicart_mobile() {
			global $woocommerce;
			$cart_total = $woocommerce->cart->get_cart_total();
			$cart_count = $woocommerce->cart->cart_contents_count;
			$cart_output = '<a href="' . $woocommerce->cart->get_cart_url() . '" title="' . __( 'View Cart', 'sitesao' ) . '"  class="cart-icon-mobile">'.$this->_get_minicart_icon2().' '.( ! empty( $cart_count ) ? '<span>' . $cart_count . '</span>' : '' ) . '</a>';
			return $cart_output;
		}
		
		public function get_minicart_sidebar() {
			global $woocommerce;
			$cart_total = $woocommerce->cart->get_cart_total();
			$cart_count = absint($woocommerce->cart->cart_contents_count);
			$cart_output = '<a href="' . $woocommerce->cart->get_cart_url() . '" title="' . __( 'View Cart', 'sitesao' ) . '"  class="cart-icon-sidebar">'.$this->_get_minicart_icon2().'<span>'.$cart_count.__(' items','sitesao').' </span> - <span>'.$cart_total.' </span> </a>';
			return $cart_output;
		}
		
		protected function _get_minicart_icon() {
			global $woocommerce;
			$cart_total = $woocommerce->cart->get_cart_total();
			$cart_count = absint( $woocommerce->cart->cart_contents_count );
			$cart_has_item = '';
			if ( ! empty( $cart_count ) ) {
				$cart_has_item = ' has-item';
			}
			
			return '<span class="minicart-icon' . $cart_has_item . '">'.$this->_get_minicart_icon2().'<span>'.$cart_count.'</span></span>';
		}
		
		public function get_topbar_minicart(){
			return $this->_get_minicart(false,false,true);
		}

		public function get_minicart(){
			return '<div class="navbar-minicart">'.$this->_get_minicart().'</div>';	
		}
		
		protected function _get_minicart( $content = false, $_flag = false ,$topbar=false) {
			global $woocommerce;
			$cart_total = $woocommerce->cart->get_cart_total();
			$cart_count = absint( $woocommerce->cart->cart_contents_count );
			$cart_count_text = $this->_cart_items_text( $cart_count );
			
			if ( version_compare( WOOCOMMERCE_VERSION, "2.1.0" ) >= 0 ) {
				$cart_url = WC()->cart->get_cart_url();
			} else {
				$cart_url = esc_url( $woocommerce->cart->get_cart_url() );
			}
			$cart_has_item = '';
			
			if ( ! empty( $cart_count ) ) {
				$cart_has_item = ' has-item';
			}
			$minicart = '';
			if ( ! $content ) {
				$minicart .= '<a class="minicart-link" href="' . $cart_url . '"><span class="minicart-icon '.$cart_has_item.'">'.$this->_get_minicart_icon2() . '<span>'.$cart_count.'</span></span>'.($topbar ? __('My Cart','sitesao'):'').'</a>';
				$minicart .= '<div class="minicart" style="display:none">';
			}
			if ( $content && $_flag ) {
				$minicart .= '<div class="minicart" style="display:none">';
			}
			if ( ! empty( $cart_count ) ) {
				$minicart .= '<div class="minicart-header">' . $cart_count_text . ' ' . __( 'in the shopping cart', 'sitesao' ) . '</div>';
				$minicart .= '<div class="minicart-body">';
				foreach ( $woocommerce->cart->cart_contents as $cart_item_key => $cart_item ) {
					
					$cart_product = $cart_item['data'];
					$product_title = $cart_product->get_title();
					$product_short_title = ( strlen( $product_title ) > 25 ) ? substr( $product_title, 0, 22 ) . '...' : $product_title;
					
					if ( $cart_product->exists() && $cart_item['quantity'] > 0 ) {
						$minicart .= '<div class="cart-product clearfix">';
						$minicart .= '<div class="cart-product-image"><a class="cart-product-img" href="' .
							 get_permalink( $cart_item['product_id'] ) . '">' . $cart_product->get_image() . '</a></div>';
						$minicart .= '<div class="cart-product-details">';
						$minicart .= '<div class="cart-product-title"><a href="' .
							 get_permalink( $cart_item['product_id'] ) . '">' .
							 apply_filters( 
								'woocommerce_cart_widget_product_title', 
								$product_short_title, 
								$cart_product ) . '</a></div>';
						$minicart .= '<div class="cart-product-quantity-price">' . $cart_item['quantity'] . ' x ' . WC()->cart->get_product_price($cart_product)  . '</div>';
						// $minicart .= '<div class="cart-product-quantity">' . __('Quantity:', 'sitesao') . ' ' .
						// $cart_item['quantity'] . '</div>';
						$minicart .= '</div>';
						
						if(function_exists('wc_get_cart_remove_url'))
							$remove_url = wc_get_cart_remove_url($cart_item_key);
						else
							$remove_url = $woocommerce->cart->get_remove_url( $cart_item_key );
						
						$minicart .= apply_filters( 
							'woocommerce_cart_item_remove_link', 
							sprintf( 
								'<a href="%s" class="remove" title="%s">&times;</a>', 
								esc_url( $remove_url ), 
								__( 'Remove this item', 'sitesao' ) ), 
							$cart_item_key );
						$minicart .= '</div>';
					}
				}
				$minicart .= '</div>';
				$minicart .= '<div class="minicart-footer">';
				//$minicart .= '<div class="minicart-total">' . __( 'Cart Subtotal', 'sitesao' ) . ' ' . $cart_total . '</div>';
				$minicart .= '<div class="minicart-actions clearfix">';
				if ( version_compare( WOOCOMMERCE_VERSION, "2.1.0" ) >= 0 ) {
// 					$cart_url = WC()->cart->get_cart_url();
					$checkout_url = WC()->cart->get_checkout_url();
					
					//$minicart .= '<a class="button" href="' . esc_url( $cart_url ) . '"><span class="text">' . __( 'View Cart', 'sitesao' ) . '</span></a>';
					$minicart .= '<a class="checkout-button button" href="' . esc_url( $checkout_url ) .'"><span class="text">' . __( 'Checkout', 'sitesao' ) . '</span></a>';
				} else {
					//$minicart .= '<a class="button" href="' . esc_url( $woocommerce->cart->get_cart_url() ) . '"><span class="text">' . __( 'View Cart', 'sitesao' ) . '</span></a>';
					$minicart .= '<a class="checkout-button button" href="' . esc_url( $woocommerce->cart->get_checkout_url() ) . '"><span class="text">' . __( 'Checkout', 'sitesao' ) . '</span></a>';
				}
				$minicart .= '</div>';
				$minicart .= '</div>';
			} else {
				$minicart .= '<div class="minicart-header no-items show">' . __( 'Your shopping bag is empty.', 'sitesao' ) . '</div>';
				$shop_page_url = "";
				if ( version_compare( WOOCOMMERCE_VERSION, "2.1.0" ) >= 0 ) {
					$shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );
				} else {
					$shop_page_url = get_permalink( wc_get_page_id( 'shop' ) );
				}
				
				$minicart .= '<div class="minicart-footer">';
				$minicart .= '<div class="minicart-actions clearfix">';
				$minicart .= '<a class="button" href="' . esc_url( $shop_page_url ) . '"><span class="text">' . __( 'Go to the shop', 'sitesao' ) . '</span></a>';
				$minicart .= '</div>';
				$minicart .= '</div>';
			}
			if ( $content && $_flag ) {
				$minicart .= '</div>';
			}
			if ( ! $content ) {
				$minicart .= '</div>';
			}
			
			return $minicart;
		}

		public function single_sharing() {
			if ( dh_get_theme_option( 'show-woo-share', 1 ) ) {
				dh_share( 
					__('share:','sitesao'), 
					dh_get_theme_option( 'woo-fb-share', 1 ), 
					dh_get_theme_option( 'woo-tw-share', 1 ), 
					dh_get_theme_option( 'woo-go-share', 1 ), 
					dh_get_theme_option( 'woo-pi-share', 0 ), 
					dh_get_theme_option( 'woo-li-share', 1 ));
			}
		}

		public function template_loop_wishlist() {
			$this->yith_wishlist_do_shortcode();
		}
		
		public function yith_wishlist_do_shortcode(){
			if ( $this->_yith_wishlist_is_active() ) {
				echo do_shortcode( '[yith_wcwl_add_to_wishlist]' );
			}
			return false;
		}
		
		public function yith_wishlist_is_active(){
			return $this->_yith_wishlist_is_active();
		}

		protected function _yith_wishlist_is_active() {
			return apply_filters('dh_yith_wishlist_is_active',defined( 'YITH_WCWL' ));
		}
		
		/**
		 * 
		 */
		public function template_loop_quickview() {
			global $product;
			if(apply_filters('dh_woocommerce_quickview', true))
				echo '<div class="shop-loop-quickview"><a data-product_id ="' . $product->get_id() . '" title="' .esc_attr__( 'Quick view', 'sitesao' ) . '" href="' . esc_url( $product->get_permalink() ) . '"><i class="fa fa-eye"></i>' .__( 'Quick view', 'sitesao' ) . '</a></div>';
		}

		public function quickview() {
			global $woocommerce, $post, $product;
			$product_id = $_POST['product_id'];
			$product = get_product( $product_id );
			$post = get_post( $product_id );
			$output = '';
			
			ob_start();
			woocommerce_get_template( 'content-quickview.php' );
			$output = ob_get_contents();
			ob_end_clean();
			
			echo trim($output);
			die();
		}

		public function template_loop_product_thumbnail() {
			$frist = $this->_product_get_frist_thumbnail();
			$thumbnail_size = 'shop_catalog';
			echo '<div class="shop-loop-thumbnail'.(apply_filters('dh_use_template_loop_product_frist_thumbnail', true) && $frist != '' ? ' shop-loop-front-thumbnail':'').'">' . woocommerce_get_product_thumbnail($thumbnail_size) . '</div>';
		}

		public function template_loop_product_frist_thumbnail() {
			if ( ( $frist = $this->_product_get_frist_thumbnail() ) != '' ) {
				echo '<div class="shop-loop-thumbnail shop-loop-back-thumbnail">' . $frist . '</div>';
			}
		}

		protected function _product_get_frist_thumbnail() {
			global $product, $post;
			$image = '';
			$current_view_mode = get_option('dh_woocommerce_view_mode',dh_get_theme_option('dh_woocommerce_view_mode','grid'));
			$thumbnail_size = 'shop_catalog';
			if ( version_compare( WOOCOMMERCE_VERSION, "2.0.0" ) >= 0 ) {
				$attachment_ids = $product->get_gallery_image_ids();
				$image_count = 0;
				if ( $attachment_ids ) {
					foreach ( $attachment_ids as $attachment_id ) {
						if ( get_post_meta( $attachment_id, '_woocommerce_exclude_image' ) )
							continue;
						
						$image = wp_get_attachment_image( $attachment_id, $thumbnail_size );
						
						$image_count++;
						if ( $image_count == 1 )
							break;
					}
				}
			} else {
				$attachments = get_posts( 
					array( 
						'post_type' => 'attachment', 
						'numberposts' => - 1, 
						'post_status' => null, 
						'post_parent' => $post->ID, 
						'post__not_in' => array( get_post_thumbnail_id() ), 
						'post_mime_type' => 'image', 
						'orderby' => 'menu_order', 
						'order' => 'ASC' ) );
				$image_count = 0;
				if ( $attachments ) {
					foreach ( $attachments as $attachment ) {
						
						if ( get_post_meta( $attachment->ID, '_woocommerce_exclude_image' ) == 1 )
							continue;
						
						$image = wp_get_attachment_image( $attachment->ID, $thumbnail_size );
						
						$image_count++;
						
						if ( $image_count == 1 )
							break;
					}
				}
			}
			return $image;
		}

		public function json_search_products() {
			$term = (string) sanitize_text_field( stripslashes( $_GET['term'] ) );
			if ( empty( $term ) )
				die();
			$post_types = array( 'product', 'product_variation' );
			if ( is_numeric( $term ) ) {
				
				$args = array( 
					'post_type' => $post_types, 
					'post_status' => 'publish', 
					'posts_per_page' => - 1, 
					'post__in' => array( 0, $term ), 
					'fields' => 'ids' );
				$args2 = array( 
					'post_type' => $post_types, 
					'post_status' => 'publish', 
					'posts_per_page' => - 1, 
					'post_parent' => $term, 
					'fields' => 'ids' );
				$args3 = array( 
					'post_type' => $post_types, 
					'post_status' => 'publish', 
					'posts_per_page' => - 1, 
					'meta_query' => array( 
						array( 'key' => '_sku', 'value' => $term, 'compare' => 'LIKE' ) ), 
					'fields' => 'ids' );
				$posts = array_unique( array_merge( get_posts( $args ), get_posts( $args2 ), get_posts( $args3 ) ) );
			} else {
				$args = array( 
					'post_type' => $post_types, 
					'post_status' => 'publish', 
					'posts_per_page' => - 1, 
					's' => $term, 
					'fields' => 'ids' );
				$args2 = array( 
					'post_type' => $post_types, 
					'post_status' => 'publish', 
					'posts_per_page' => - 1, 
					'meta_query' => array( 
						array( 'key' => '_sku', 'value' => $term, 'compare' => 'LIKE' ) ), 
					'fields' => 'ids' );
				$posts = array_unique( array_merge( get_posts( $args ), get_posts( $args2 ) ) );
			}
			$found_products = array();
			if ( $posts )
				foreach ( $posts as $post ) {
					$product = get_product( $post );
					$found_products[$post] = $this->_formatted_name( $product );
				}
			wp_send_json( $found_products );
		}

		protected function _formatted_name( WC_Product $product ) {
			if ( $product->get_sku() ) {
				$identifier = $product->get_sku();
			} else {
				$identifier = '#' . $product->id;
			}
			
			return sprintf( __( '%s &ndash; %s', 'sitesao' ), $identifier, $product->get_title() );
		}
		
		public function _get_minicart_icon2(){
			return apply_filters('dh_woocommerce_minicart_icon','<i class="fa fa-shopping-cart"></i> ');
		}
		
		public function product_tax_add_heading_fields($taxonomy){
			?>
			<div class="form-field">
				<label><?php _e( 'Heading Background', 'sitesao' ); ?></label>
				<div id="product_cat_heading_thumbnail" style="float:left;margin-right:10px;">
					<img src="<?php echo woocommerce_placeholder_img_src(); ?>" width="60px" height="60px" />
				</div>
				<div style="line-height:60px;">
					<input type="hidden" id="product_cat_heading_thumbnail_id" name="product_cat_heading_thumbnail_id" />
					<button type="submit" class=" button product_cat_heding_upload"><?php _e('Upload/Add image', 'sitesao'); ?></button>
					<button type="submit" class=" button product_cat_heding_remove"><?php _e('Remove image', 'sitesao'); ?></button>
				</div>
				<script type="text/javascript">
			
					 // Only show the "remove image" button when needed
					 if ( ! jQuery('#product_cat_heading_thumbnail_id').val() )
						 jQuery('.product_cat_heding_remove').hide();
			
					// Uploading files
					var product_cat_heading_file_frame;
			
					jQuery(document).on( 'click', '.product_cat_heding_upload', function( event ){
			
						event.preventDefault();
			
						// If the media frame already exists, reopen it.
						if ( product_cat_heading_file_frame ) {
							product_cat_heading_file_frame.open();
							return;
						}
			
						// Create the media frame.
						product_cat_heading_file_frame = wp.media.frames.downloadable_file = wp.media({
							title: '<?php echo esc_js(__( 'Choose an image', 'sitesao' )); ?>',
							button: {
								text: '<?php echo esc_js(__( 'Use image', 'sitesao' )); ?>',
							},
							multiple: false
						});
			
						// When an image is selected, run a callback.
						product_cat_heading_file_frame.on( 'select', function() {
							attachment = product_cat_heading_file_frame.state().get('selection').first().toJSON();
			
							jQuery('#product_cat_heading_thumbnail_id').val( attachment.id );
							jQuery('#product_cat_heading_thumbnail img').attr('src', attachment.url );
							jQuery('.product_cat_heding_remove').show();
						});
			
						// Finally, open the modal.
						product_cat_heading_file_frame.open();
					});
			
					jQuery(document).on( 'click', '.product_cat_heding_remove', function( event ){
						jQuery('#product_cat_heading_thumbnail img').attr('src', '<?php echo woocommerce_placeholder_img_src(); ?>');
						jQuery('#product_cat_heading_thumbnail_id').val('');
						jQuery('.product_cat_heding_remove').hide();
						return false;
					});
			
				</script>
				<div class="clear"></div>
			</div>
			<div class="form-field">
				<label for="product_cat_heading_title"><?php _e('Heading Title')?></label>
				<input id="product_cat_heading_title" type="text" aria-required="true" size="40" value="" name="product_cat_heading_title">
			</div>
			<div class="form-field">
				<label for="product_cat_heading_sub_title"><?php _e('Heading Sub Title')?></label>
				<input id="product_cat_heading_sub_title" type="text" aria-required="true" size="40" value="" name="product_cat_heading_sub_title">
			</div>
			<?php
		}
		
		public function product_tax_edit_heading_fields($term, $taxonomy){
			global $woocommerce;
			$image 			= '';
			$thumbnail_id 	= get_woocommerce_term_meta( $term->term_id, 'product_cat_heading_thumbnail_id', true );
			if ($thumbnail_id) :
				$image = wp_get_attachment_url( $thumbnail_id );
			else :
				$image = woocommerce_placeholder_img_src();
			endif;
			
			$product_cat_heading_title = get_woocommerce_term_meta( $term->term_id, 'product_cat_heading_title', true );
			$product_cat_heading_sub_title = get_woocommerce_term_meta( $term->term_id, 'product_cat_heading_sub_title', true );
			
			?>
			<tr class="form-field">
				<th scope="row" valign="top">
					<label><?php _e( 'Heading Background', 'sitesao' ); ?></label>
				</th>
				<td>
					<div id="product_cat_heading_thumbnail" style="float:left;margin-right:10px;">
						<img src="<?php echo $image; ?>" width="60px" height="60px" />
					</div>
					<div style="line-height:60px;">
						<input type="hidden" value="<?php echo esc_attr($thumbnail_id)?>" id="product_cat_heading_thumbnail_id" name="product_cat_heading_thumbnail_id" />
						<button type="submit" class="button product_cat_heding_upload"><?php _e('Upload/Add image', 'sitesao'); ?></button>
						<button type="submit" class="button product_cat_heding_remove"><?php _e('Remove image', 'sitesao'); ?></button>
					</div>
					<script type="text/javascript">
				
						 // Only show the "remove image" button when needed
						 if ( ! jQuery('#product_cat_heading_thumbnail_id').val() )
							 jQuery('.product_cat_heding_remove').hide();
				
						// Uploading files
						var product_cat_heading_file_frame;
				
						jQuery(document).on( 'click', '.product_cat_heding_upload', function( event ){
				
							event.preventDefault();
				
							// If the media frame already exists, reopen it.
							if ( product_cat_heading_file_frame ) {
								product_cat_heading_file_frame.open();
								return;
							}
				
							// Create the media frame.
							product_cat_heading_file_frame = wp.media.frames.downloadable_file = wp.media({
								title: '<?php echo esc_js(__( 'Choose an image', 'sitesao' )); ?>',
								button: {
									text: '<?php echo esc_js(__( 'Use image', 'sitesao' )); ?>',
								},
								multiple: false
							});
				
							// When an image is selected, run a callback.
							product_cat_heading_file_frame.on( 'select', function() {
								attachment = product_cat_heading_file_frame.state().get('selection').first().toJSON();
				
								jQuery('#product_cat_heading_thumbnail_id').val( attachment.id );
								jQuery('#product_cat_heading_thumbnail img').attr('src', attachment.url );
								jQuery('.product_cat_heding_remove').show();
							});
				
							// Finally, open the modal.
							product_cat_heading_file_frame.open();
						});
				
						jQuery(document).on( 'click', '.product_cat_heding_remove', function( event ){
							jQuery('#product_cat_heading_thumbnail img').attr('src', '<?php echo woocommerce_placeholder_img_src(); ?>');
							jQuery('#product_cat_heading_thumbnail_id').val('');
							jQuery('.product_cat_heding_remove').hide();
							return false;
						});
				
					</script>
				</td>
			</tr>
			<tr class="form-field">
				<th scope="row" valign="top"><label for="product_cat_heading_title"><?php _e('Heading Title')?></label></th>
				<td><input id="product_cat_heading_title" type="text" aria-required="true" size="40" value="<?php echo esc_attr($product_cat_heading_title)?>" name="product_cat_heading_title"></td>
			</tr>
			<tr class="form-field">
				<th scope="row" valign="top"><label for="product_cat_heading_sub_title"><?php _e('Heading Sub Title')?></label></th>
				<td><input id="product_cat_heading_sub_title" type="text" aria-required="true" size="40" value="<?php echo esc_attr($product_cat_heading_sub_title)?>" name="product_cat_heading_sub_title"></td>
			</tr>
			<?php
		}
		
		public function product_cat_heading_save( $term_id, $tt_id, $taxonomy ) {
			$fields = array(
				'product_cat_heading_thumbnail_id',
				'product_cat_heading_title',
				'product_cat_heading_sub_title',
			);
			foreach ($fields as $field){
				if(isset($_POST[$field])){
					$value = !empty($_POST[$field]) ? wp_kses_post($_POST[$field]):'';
					update_woocommerce_term_meta( $term_id, $field, $value );
				}
			}
		}
		
		public function product_categories_grid_shortcode($atts){
			$atts = shortcode_atts( array(
				'number'     => null,
				'orderby'    => 'name',
				'order'      => 'ASC',
				'columns'    => '4',
				'hide_empty' => 0,
				'parent'     => '',
				'ids'        => ''
			), $atts );
			
			if ( isset( $atts['ids'] ) ) {
				$ids = explode( ',', $atts['ids'] );
				$ids = array_map( 'trim', $ids );
			} else {
				$ids = array();
			}
			if ( $atts['orderby'] == 'order' ) {
				$args['menu_order'] = 'ASC';
				$args['orderby'] 	= 'name';
			} else {
				$args['orderby']    = $atts['orderby'];
			}
			$hide_empty = ( $atts['hide_empty'] == true || $atts['hide_empty'] == 1 ) ? 1 : 0;
	
			// get terms and workaround WP bug with parents/pad counts
			$args = array(
				'orderby'    => $atts['orderby'],
				'order'      => $atts['order'],
				'hide_empty' => $hide_empty,
				'include'    => $ids,
				'pad_counts' => true,
				'child_of'   => $atts['parent']
			);
	
			$product_categories = get_terms( 'product_cat', $args );
	
			if ( '' !== $atts['parent'] ) {
				$product_categories = wp_list_filter( $product_categories, array( 'parent' => $atts['parent'] ) );
			}
	
			if ( $hide_empty ) {
				foreach ( $product_categories as $key => $category ) {
					if ( $category->count == 0 ) {
						unset( $product_categories[ $key ] );
					}
				}
			}
	
			if ( $atts['number'] ) {
				$product_categories = array_slice( $product_categories, 0, $atts['number'] );
			}
			ob_start();
			if ( $product_categories ) {
				?>
				<div class="product-categories-grid">
					<div class="product-categories-grid-wrap row clearfix">
						<?php 
						$w=0;
						$layout = 'wall';
						foreach ($product_categories as $category):
						?>
							<?php 
							// Wall layout
							$w++;
							if($layout == 'wall'):
							$wall_open_row=false;
							?>
							<?php if ($w == '5' || $w == '12'): $wall_open_row = true;?>
							<div class="product-category-wall wall-row">
							<?php endif;?>
							<div class="wall-col <?php 
								
								if($w == '1' || $w == '8'): 
									echo 'col-md-6 col-sm-12 title-in'; 
								elseif ($w=='2' || $w=='3' || $w=='9' || $w=='10'):
									echo 'col-md-3 col-sm-12 title-out padding-100';
								elseif ($w =='4' || $w == '11'):
									echo 'col-md-6 col-sm-12 title-out title-pos-top-left';
								elseif ($w=='5' || $w=='6' || $w=='7' || $w == '12' || $w == '13' || $w == '14'): 
									echo 'col-sm-4 title-out height-auto'; 
								endif;
								
								if($w == '5' || $w == '7' || $w == '11' || $w == '13'){
									echo ' wall-bg';
								}
								if($w == '8'){
									echo ' pull-right';
								}
								if ($w !='4' || $w != '10'){
									echo ' product-category-wall ';
								}
								?>">
							<?php
							endif;
							?>
							<a href="<?php echo get_term_link( $category->slug, 'product_cat' ); ?>">
								<div class="product-category-grid-item">
									<div class="product-category-grid-item-wrap">
										<?php 
										$thumbnail_id  			= get_woocommerce_term_meta( $category->term_id, 'thumbnail_id', true  );
										if ( $thumbnail_id ) {
											$image = wp_get_attachment_url( $thumbnail_id  );
										} else {
											$image = wc_placeholder_img_src();
										}
										?>
										<div class="product-category-grid-featured-wrap">
											<div class="product-category-grid-featured" <?php if(!empty($image)):?> style="background-image: url(<?php echo esc_url($image)?>)"<?php endif;?>></div>
										</div>
										<div class="product-category-grid-featured-summary">
											<h3>
												<?php
													echo $category->name;
												?>
												<?php if($short_desc = get_woocommerce_term_meta( $category->term_id, 'product_cat_short_description', true )):?>
												<small><?php echo esc_html($short_desc)?></small>
												<?php endif;?>
											</h3>
										</div>
									</div>
								</div>
							</a>
							<?php 
							// Wall layout
							if($layout == 'wall'):
							?>
							</div>
							<?php if ($w == '7' || $w == '14'): ?>
							</div>
							<?php elseif ($w > 5 && $w < 8 && $w == count($product_categories)):?>
								<?php echo '</div>'?>
							<?php elseif ($w >= 12 && $w < 14 && $w == count($product_categories)):?>
								<?php echo '</div>'?>
							<?php
							endif;
							?>
						<?php
						endif;
						?>
						<?php if($w == '14') $w = 0;?>
						<?php 
						endforeach;
						?>
					</div>
				</div>
				<?php
			}
			return ob_get_clean();
		}
	}
	new DH_Woocommerce();
endif;
